@@ -47,7 +47,7 @@ typedef QList<QDomElement> ToolBarList;
 
 namespace KDEPrivate
 {
-/**
+/*
  * Return a list of toolbar elements given a toplevel element
  */
 static ToolBarList findToolBars(const QDomElement &start)
@@ -72,7 +72,12 @@ static ToolBarList findToolBars(const QDomElement &start)
 class XmlData
 {
 public:
-    enum XmlType { Shell = 0, Part, Local, Merged };
+    enum XmlType {
+        Shell = 0,
+        Part,
+        Local,
+        Merged
+    };
 
     explicit XmlData(XmlType xmlType, const QString &xmlFile, KActionCollection *collection)
         : m_isModified(false)
@@ -122,7 +127,7 @@ public:
         return m_document;
     }
 
-    /**
+    /*
      * Return the text (user-visible name) of a given toolbar
      */
     QString toolBarText(const QDomElement &it) const;
@@ -385,7 +390,7 @@ void IconTextEditDialog::slotTextChanged(const QString &text)
 class KEditToolBarWidgetPrivate
 {
 public:
-    /**
+    /*
      *
      * @param collection In the old-style constructor, this is the collection passed
      * to the KEditToolBar constructor.
@@ -441,7 +446,7 @@ public:
         return xml_file.isEmpty() ? m_componentName + QLatin1String("ui.rc") : xml_file;
     }
 
-    /**
+    /*
      * Load in the specified XML file and dump the raw xml
      */
     QString loadXMLFile(const QString &_xml_file)
@@ -459,7 +464,7 @@ public:
         return raw_xml;
     }
 
-    /**
+    /*
      * Look for a given item in the current toolbar
      */
     QDomElement findElementForToolBarItem(const ToolBarItem *item) const
@@ -1037,7 +1042,7 @@ void KEditToolBarWidgetPrivate::setupLayout()
     activeListSearchLine->setPlaceholderText(i18n("Filter"));
 
     // "change icon" button
-    m_changeIcon = new QPushButton(i18nc("@action:button", "Change &Icon..."), m_widget);
+    m_changeIcon = new QPushButton(i18nc("@action:button", "Change &Icon…"), m_widget);
     m_changeIcon->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-icons")));
     m_changeIcon->setEnabled(m_activeList->currentItem());
 
@@ -1046,7 +1051,7 @@ void KEditToolBarWidgetPrivate::setupLayout()
     });
 
     // "change icon text" button
-    m_changeIconText = new QPushButton(i18nc("@action:button", "Change Te&xt..."), m_widget);
+    m_changeIconText = new QPushButton(i18nc("@action:button", "Change Te&xt…"), m_widget);
     m_changeIconText->setIcon(QIcon::fromTheme(QStringLiteral("edit-rename")));
     m_changeIconText->setEnabled(m_activeList->currentItem() != nullptr);
 
